var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
var __read = (this && this.__read) || function (o, n) {
    var m = typeof Symbol === "function" && o[Symbol.iterator];
    if (!m) return o;
    var i = m.call(o), r, ar = [], e;
    try {
        while ((n === void 0 || n-- > 0) && !(r = i.next()).done) ar.push(r.value);
    }
    catch (error) { e = { error: error }; }
    finally {
        try {
            if (r && !r.done && (m = i["return"])) m.call(i);
        }
        finally { if (e) throw e.error; }
    }
    return ar;
};
var __spread = (this && this.__spread) || function () {
    for (var ar = [], i = 0; i < arguments.length; i++) ar = ar.concat(__read(arguments[i]));
    return ar;
};
var __values = (this && this.__values) || function (o) {
    var m = typeof Symbol === "function" && o[Symbol.iterator], i = 0;
    if (m) return m.call(o);
    return {
        next: function () {
            if (o && i >= o.length) o = void 0;
            return { value: o && o[i++], done: !o };
        }
    };
};
import { detach, types } from "mobx-state-tree";
import { observe, toJS } from "mobx";
import { mappings } from "../Common";
import { createType } from "../Type";
import { isArray, unique } from "../utils";
import { createValue } from "../Value";
import { createMeta } from "../Meta";
mappings.array = types.late("Array", createArray);
var NArray;
export var ArrayMeta = types.compose("ArrayMeta", createMeta(types.array(types.frozen), [], "list", "layout", "checkboxes"), types.model({}));
export function createArray() {
    if (!NArray) {
        var Array_1 = types
            .compose("Array", createValue("array", types.array(types.frozen), [], ArrayMeta, {
            component: "list"
        }), types.model({
            additionalItems: types.maybe(types.boolean),
            elements: types.optional(types.array(types.late(createType)), []),
            items: types.optional(types.frozen, null),
            maxItems: types.maybe(types.number),
            minItems: types.maybe(types.number),
            uniqueItems: types.maybe(types.boolean)
        }))
            .views(function (it) { return ({
            get dynamic() {
                return !isArray(it.items);
            }
        }); })
            .actions(function (it) { return ({
            updateIndexValue: function (index, value) {
                it.meta.value[index] = value;
                if (it.elements.length > index) {
                    // TODO: Need to fix for all types
                    it.elements[index].setValue(value);
                }
            },
            removeIndexValue: function (index) {
                it.meta.value.splice(index, 1);
            }
        }); })
            .actions(function (it) { return ({
            getConfig: function (value, index, element) {
                var Type = createType();
                var type = Type.create(__assign({}, element, { meta: {
                        value: toJS(value)
                    } }));
                observe(type.meta, "value", function (changes) {
                    it.updateIndexValue(index, type.meta.value);
                });
                return type;
            }
        }); })
            .actions(function (it) { return ({
            updateElements: function (values) {
                var _a;
                if (values != null && it.items !== null) {
                    it.elements.length = 0;
                    if (!isArray(it.items)) {
                        (_a = it.elements).push.apply(_a, __spread(values.map(function (value, index) {
                            return it.getConfig(value, index, it.items);
                        })));
                    }
                    else {
                        it.items.forEach(function (item, index) {
                            it.elements.push(it.getConfig(values.length > index ? values[index] : null, index, item));
                        });
                    }
                }
            },
            push: function () {
                if (it.dynamic) {
                    var meta = it.items.meta;
                    var value = meta ? meta.default : undefined;
                    var index = it.meta.value.length;
                    it.updateIndexValue(index, value);
                    it.elements.push(it.getConfig(value, index, it.items));
                    it.validate();
                }
            },
            remove: function (index) {
                if (it.dynamic) {
                    it.removeIndexValue(index);
                    var element = it.elements[index];
                    detach(element);
                    // it.elements.splice(index, 1);
                    it.validate();
                }
            }
        }); })
            .actions(function (it) { return ({
            afterCreate: function () {
                if (it.minItems !== null && it.minItems < 0) {
                    throw new TypeError("minItems can not be negative");
                }
                if (it.maxItems !== null && it.maxItems < 0) {
                    throw new TypeError("maxItems can not be negative");
                }
                it.updateElements(toJS(it.meta.value));
            }
        }); })
            .actions(function (it) { return ({
            doValidate: function (value) {
                var e_1, _a;
                var errors = it.doValidateBase(value);
                if (value === null) {
                    return errors;
                }
                if (it.minItems !== null && value.length < it.minItems) {
                    errors.push("should NOT have less than " + it.minItems + " items");
                }
                if (it.maxItems !== null && value.length > it.maxItems) {
                    errors.push("should NOT have more than " + it.maxItems + " items");
                }
                if (it.uniqueItems !== null &&
                    it.uniqueItems &&
                    value.length !== unique(value).length) {
                    errors.push("should NOT have duplicate items");
                }
                if (isArray(it.items) &&
                    it.additionalItems !== null &&
                    it.additionalItems === false) {
                    if (value.length > it.items.length) {
                        errors.push("should NOT have additional items");
                    }
                }
                if (it.elements !== null) {
                    try {
                        for (var _b = __values(it.elements), _c = _b.next(); !_c.done; _c = _b.next()) {
                            var element = _c.value;
                            element.validate();
                        }
                    }
                    catch (e_1_1) { e_1 = { error: e_1_1 }; }
                    finally {
                        try {
                            if (_c && !_c.done && (_a = _b.return)) _a.call(_b);
                        }
                        finally { if (e_1) throw e_1.error; }
                    }
                }
                return errors;
            },
            setValue: function (value) {
                it.meta.setValue(value);
                it.updateElements(toJS(value));
            }
        }); })
            .views(function (it) { return ({
            getFieldErrors: function () {
                return it.elements.reduce(function (errors, element, index) {
                    errors.items[index] = element
                        .getFieldErrors
                        ? element.getFieldErrors()
                        : toJS(element.errors);
                    return errors;
                }, { errors: toJS(it.errors), items: [] });
            },
            get data() {
                return it.elements.reduce(function (data, element, index) {
                    data[index] = element.data;
                    return data;
                }, __spread(toJS(it.meta.value || [])));
            },
            get valid() {
                return (it.errors.length === 0 &&
                    it.elements.every(function (element) { return element.valid; }));
            },
            get modified() {
                return it.elements.some(function (element) { return element.modified; });
            },
            get validating() {
                return (it._validating ||
                    it.elements.some(function (element) { return element.validating; }));
            }
        }); });
        NArray = Array_1;
    }
    return NArray;
}
//# sourceMappingURL=Array.js.map