import { types } from "mobx-state-tree";
import { mappings } from "../Common";
import { decimals } from "../utils";
import { createValue } from "../Value";
import { createMeta } from "../Meta";
export var NumberMeta = types.compose("NumberMeta", createMeta(types.number, 0, "number", "range", "radios", "text", "select"), types.model({
    step: types.maybe(types.number)
}));
// tslint:disable-next-line:variable-name
export var Number = types
    .compose("Number", createValue("number", types.number, 0, NumberMeta, { component: "text" }), types.model({
    maximum: types.maybe(types.number),
    minimum: types.maybe(types.number),
    multipleOf: types.maybe(types.number)
}))
    .actions(function (it) { return ({
    afterCreate: function () {
        if (it.multipleOf !== null && it.multipleOf <= 0) {
            throw new TypeError("multipleOf can not be " + (it.multipleOf === 0 ? "zero" : "negative"));
        }
    }
}); })
    .actions(function (it) { return ({
    doValidate: function (value) {
        var errors = it.doValidateBase(value);
        if (it.minimum !== null && value < it.minimum) {
            errors.push("should NOT be lesser than " + it.minimum);
        }
        if (it.maximum !== null && value > it.maximum) {
            errors.push("should NOT be greater than " + it.maximum);
        }
        if (it.multipleOf !== null && it.multipleOf > 1) {
            var multiplier = Math.pow(10, Math.max(decimals(value), decimals(it.multipleOf)));
            if (Math.round(value * multiplier) %
                Math.round(it.multipleOf * multiplier) !==
                0) {
                errors.push("should be multiple of " + it.multipleOf);
            }
        }
        return errors;
    }
}); });
mappings.number = Number;
export function createNumber() {
    return Number;
}
//# sourceMappingURL=Number.js.map