import { IModelType } from "mobx-state-tree";
import { IFieldErrors, ILayout } from "../Common";
import { IValue, IValueAttrs, IValueConfig } from "../Value";
import { IType, ITypeConfig, ITypeMetaProps } from "../Type";
import { IMeta, IMetaAttrs, IMetaConfig } from "../Meta";
export declare type IObjectComponent = "grid" | "layout" | "list";
export interface IObjectMetaAttrs extends IMetaAttrs<object | null, IObjectComponent> {
    readonly layout?: ILayout | null;
}
export interface IObjectMetaConfig extends IMetaConfig<object | null, IObjectComponent>, IObjectMetaAttrs {
}
export interface IObjectMeta extends IMeta<object | null, IObjectComponent>, IObjectMetaAttrs {
}
export declare type IObjectType = "object";
export interface IObjectMetaProps extends IObjectMetaConfig {
    readonly type: IObjectType;
    readonly properties?: {
        [key: string]: ITypeMetaProps;
    };
}
export interface IObjectAttrs extends IValueAttrs<object | null> {
    readonly required?: string[] | null;
    readonly minProperties?: number | null;
    readonly maxProperties?: number | null;
}
export interface IObjectConfig extends IValueConfig<object | null, IObjectType, IObjectComponent, IObjectMetaConfig>, Partial<IObjectAttrs> {
    readonly properties?: {
        [key: string]: ITypeConfig;
    };
    readonly additionalProperties?: boolean | ITypeConfig | null;
}
export interface IObject extends IObjectAttrs, IValue<object | null, IObjectType, IObjectComponent, IObjectMetaConfig, IObjectMeta> {
    readonly properties?: ReadonlyMap<string, IType> | null;
    readonly additionalProperties?: boolean | IType | null;
    readonly fields: IType[];
    readonly modified: boolean;
    getProperty(property: string): IType | undefined;
    getProperties(): string[];
    getFieldErrors(): IFieldErrors;
}
export declare const ObjectMeta: IModelType<Partial<IObjectMetaConfig>, IObjectMeta>;
export declare function createObject(): IModelType<Partial<IObjectConfig>, IObject>;
