"use strict";
// tslint:disable:max-file-line-count
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var Array_1 = require("./Array");
var mobx_1 = require("mobx");
describe("Array testing", function () {
    var config = {
        items: {
            type: "number"
        },
        meta: {
            component: "layout",
            sequence: 30
        },
        title: "naguvan",
        type: "array"
    };
    var Array = Array_1.createArray();
    test("check array default meta", function () {
        var type = Array.create();
        expect(type.meta).not.toBeNull();
        expect(type.meta.component).toBe("list");
        expect(type.meta.sequence).toBeNull();
        expect(type.meta.help).toBeNull();
    });
    test("test array meta", function () {
        var type = Array.create(config);
        expect(type.meta).not.toBeNull();
        expect(type.meta.component).toBe("layout");
        expect(type.meta.help).toBeNull();
        expect(type.meta.sequence).toBe(30);
    });
    test("create array type", function () {
        var type = Array.create(config);
        expect(type.type).toBe("array");
        expect(type.title).toBe("naguvan");
        expect(type.data).toEqual([]);
        expect(type.additionalItems).toBeNull();
        expect(type.maxItems).toBeNull();
        expect(type.minItems).toBeNull();
        expect(type.uniqueItems).toBeNull();
        expect(type.items).not.toBeNull();
        expect(type.items.type).toBe("number");
    });
    test("validate array valid values", function () {
        var type = Array.create(__assign({}, config));
        expect(type.type).toBe("array");
        type.setValue([1, 2, 3]);
        type.validate();
        expect(type.data).toEqual([1, 2, 3]);
        expect(type.valid).toBe(true);
    });
    test("validate array invalid values", function () {
        var type = Array.create(__assign({}, config));
        expect(type.type).toBe("array");
        type.setValue([1, "2", 3, false]);
        type.validate();
        expect(type.data).toEqual([1, "2", 3, false]);
        expect(type.valid).toBe(false);
        expect(mobx_1.toJS(type.elements[1].errors)).toEqual(["Value is not a number"]);
        expect(mobx_1.toJS(type.elements[3].errors)).toEqual(["Value is not a number"]);
    });
    test("validate array invalid values with range", function () {
        var type = Array.create(__assign({}, config, { items: { type: "number", maximum: 5 } }));
        expect(type.type).toBe("array");
        type.setValue([1, 4, 6]);
        type.validate();
        expect(type.data).toEqual([1, 4, 6]);
        expect(type.valid).toBe(false);
        expect(mobx_1.toJS(type.elements[2].errors)).toEqual([
            "should NOT be greater than 5"
        ]);
    });
    test("validate tuple valid values", function () {
        var type = Array.create({
            items: [
                { type: "number", maximum: 5, minimum: 2 },
                { type: "string", maxLength: 10 },
                {
                    enum: ["NW", "NE", "SW", "SE"],
                    type: "string"
                }
            ],
            type: "array"
        });
        expect(type.type).toBe("array");
        type.setValue([3, "naguvan", "NW"]);
        type.validate();
        expect(type.data).toEqual([3, "naguvan", "NW"]);
        expect(type.valid).toBe(true);
        expect(mobx_1.toJS(type.errors)).toEqual([]);
    });
    test("validate tuple invalid values", function () {
        var type = Array.create({
            items: [
                { type: "number", maximum: 5, minimum: 2 },
                { type: "string", maxLength: 5 },
                {
                    enum: ["NW", "NE", "SW", "SE"],
                    type: "string"
                }
            ],
            type: "array"
        });
        expect(type.type).toBe("array");
        type.setValue([7, "naguvan", "EF"]);
        type.validate();
        expect(type.data).toEqual([7, "naguvan", "EF"]);
        expect(type.valid).toBe(false);
        expect(mobx_1.toJS(type.errors)).toEqual([]);
        expect(mobx_1.toJS(type.elements[0].errors)).toEqual([
            "should NOT be greater than 5"
        ]);
        expect(mobx_1.toJS(type.elements[1].errors)).toEqual([
            "should NOT be longer than 5 characters"
        ]);
        expect(mobx_1.toJS(type.elements[2].errors)).toEqual([
            "should be equal to one of the allowed values [NW, NE, SW, SE]"
        ]);
    });
    test("validate tuple invalid values", function () {
        var type = Array.create({
            items: [
                { type: "number", maximum: 5, minimum: 2 },
                { type: "string", maxLength: 5 },
                {
                    enum: ["NW", "NE", "SW", "SE"],
                    type: "string"
                }
            ],
            type: "array"
        });
        expect(type.type).toBe("array");
        type.setValue([7, "naguvan", "EF"]);
        type.validate();
        expect(type.data).toEqual([7, "naguvan", "EF"]);
        expect(type.valid).toBe(false);
        expect(mobx_1.toJS(type.errors)).toEqual([]);
        expect(mobx_1.toJS(type.elements[0].errors)).toEqual([
            "should NOT be greater than 5"
        ]);
        expect(mobx_1.toJS(type.elements[1].errors)).toEqual([
            "should NOT be longer than 5 characters"
        ]);
        expect(mobx_1.toJS(type.elements[2].errors)).toEqual([
            "should be equal to one of the allowed values [NW, NE, SW, SE]"
        ]);
    });
    test("validate tuple valid few items", function () {
        var type = Array.create({
            items: [
                { type: "number", maximum: 5, minimum: 2 },
                { type: "string", maxLength: 7 },
                {
                    enum: ["NW", "NE", "SW", "SE"],
                    type: "string"
                }
            ],
            type: "array"
        });
        expect(type.type).toBe("array");
        type.setValue([3, "naguvan"]);
        type.validate();
        expect(type.data).toEqual([3, "naguvan", null]);
        expect(type.valid).toBe(false);
        expect(mobx_1.toJS(type.errors)).toEqual([]);
        expect(mobx_1.toJS(type.elements[0].errors)).toEqual([]);
        expect(mobx_1.toJS(type.elements[1].errors)).toEqual([]);
        // expect(toJS(type.elements[2].errors!)).toEqual([
        //     'should be equal to one of the allowed values [NW, NE, SW, SE]'
        // ]);
        expect(mobx_1.toJS(type.elements[2].errors)).toEqual(["Value is not a string"]);
    });
    test("validate tuple valid more items", function () {
        var type = Array.create({
            items: [
                { type: "number", maximum: 5, minimum: 2 },
                { type: "string", maxLength: 7 },
                {
                    enum: ["NW", "NE", "SW", "SE"],
                    type: "string"
                }
            ],
            type: "array"
        });
        expect(type.type).toBe("array");
        type.setValue([3, "naguvan", "NE", "extra"]);
        type.validate();
        expect(type.data).toEqual([3, "naguvan", "NE", "extra"]);
        expect(type.valid).toBe(true);
        expect(mobx_1.toJS(type.errors)).toEqual([]);
        expect(mobx_1.toJS(type.elements[0].errors)).toEqual([]);
        expect(mobx_1.toJS(type.elements[1].errors)).toEqual([]);
        expect(mobx_1.toJS(type.elements[2].errors)).toEqual([]);
    });
    test("validate tuple valid not allowing additional items", function () {
        var type = Array.create({
            additionalItems: false,
            items: [
                { type: "number", maximum: 5, minimum: 2 },
                { type: "string", maxLength: 7 },
                {
                    enum: ["NW", "NE", "SW", "SE"],
                    type: "string"
                }
            ],
            type: "array"
        });
        expect(type.type).toBe("array");
        type.setValue([3, "naguvan", "NE", "extra"]);
        type.validate();
        expect(type.data).toEqual([3, "naguvan", "NE", "extra"]);
        expect(type.valid).toBe(false);
        expect(mobx_1.toJS(type.errors)).toEqual(["should NOT have additional items"]);
    });
    test("validate min items", function () {
        var type = Array.create({
            minItems: 5,
            type: "array"
        });
        expect(type.type).toBe("array");
        type.setValue([3, "naguvan", "NE", "extra"]);
        type.validate();
        expect(type.data).toEqual([3, "naguvan", "NE", "extra"]);
        expect(type.valid).toBe(false);
        expect(mobx_1.toJS(type.errors)).toEqual(["should NOT have less than 5 items"]);
    });
    test("validate max items", function () {
        var type = Array.create({
            maxItems: 3,
            type: "array"
        });
        expect(type.type).toBe("array");
        type.setValue([3, "naguvan", "NE", "extra"]);
        type.validate();
        expect(type.data).toEqual([3, "naguvan", "NE", "extra"]);
        expect(type.valid).toBe(false);
        expect(mobx_1.toJS(type.errors)).toEqual(["should NOT have more than 3 items"]);
    });
    test("validate unique items", function () {
        var type = Array.create({
            type: "array",
            uniqueItems: true
        });
        expect(type.type).toBe("array");
        type.setValue([3, "naguvan", 3, "NE", "NE", "extra"]);
        type.validate();
        expect(type.data).toEqual([3, "naguvan", 3, "NE", "NE", "extra"]);
        expect(type.valid).toBe(false);
        expect(mobx_1.toJS(type.errors)).toEqual(["should NOT have duplicate items"]);
    });
    test("validate value types", function () {
        var type = Array.create({
            items: {
                type: "number"
            },
            meta: {
                value: [1, 2, 3]
            },
            title: "Array",
            type: "array"
        });
        expect(type.type).toBe("array");
        type.setValue([1, 2, 3]);
        type.validate();
        expect(type.data).toEqual([1, 2, 3]);
        expect(type.valid).toBe(true);
        expect(type.elements.length).toBe(3);
    });
});
//# sourceMappingURL=Array.test.js.map