"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var mobx_state_tree_1 = require("mobx-state-tree");
var Common_1 = require("../Common");
var utils_1 = require("../utils");
var Value_1 = require("../Value");
var Meta_1 = require("../Meta");
exports.NumberMeta = mobx_state_tree_1.types.compose("NumberMeta", Meta_1.createMeta(mobx_state_tree_1.types.number, 0, "number", "range", "radios", "text", "select"), mobx_state_tree_1.types.model({
    step: mobx_state_tree_1.types.maybe(mobx_state_tree_1.types.number)
}));
// tslint:disable-next-line:variable-name
exports.Number = mobx_state_tree_1.types
    .compose("Number", Value_1.createValue("number", mobx_state_tree_1.types.number, 0, exports.NumberMeta, { component: "text" }), mobx_state_tree_1.types.model({
    maximum: mobx_state_tree_1.types.maybe(mobx_state_tree_1.types.number),
    minimum: mobx_state_tree_1.types.maybe(mobx_state_tree_1.types.number),
    multipleOf: mobx_state_tree_1.types.maybe(mobx_state_tree_1.types.number)
}))
    .actions(function (it) { return ({
    afterCreate: function () {
        if (it.multipleOf !== null && it.multipleOf <= 0) {
            throw new TypeError("multipleOf can not be " + (it.multipleOf === 0 ? "zero" : "negative"));
        }
    }
}); })
    .actions(function (it) { return ({
    doValidate: function (value) {
        var errors = it.doValidateBase(value);
        if (it.minimum !== null && value < it.minimum) {
            errors.push("should NOT be lesser than " + it.minimum);
        }
        if (it.maximum !== null && value > it.maximum) {
            errors.push("should NOT be greater than " + it.maximum);
        }
        if (it.multipleOf !== null && it.multipleOf > 1) {
            var multiplier = Math.pow(10, Math.max(utils_1.decimals(value), utils_1.decimals(it.multipleOf)));
            if (Math.round(value * multiplier) %
                Math.round(it.multipleOf * multiplier) !==
                0) {
                errors.push("should be multiple of " + it.multipleOf);
            }
        }
        return errors;
    }
}); });
Common_1.mappings.number = exports.Number;
function createNumber() {
    return exports.Number;
}
exports.createNumber = createNumber;
//# sourceMappingURL=Number.js.map