"use strict";
var __assign = (this && this.__assign) || function () {
    __assign = Object.assign || function(t) {
        for (var s, i = 1, n = arguments.length; i < n; i++) {
            s = arguments[i];
            for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p))
                t[p] = s[p];
        }
        return t;
    };
    return __assign.apply(this, arguments);
};
Object.defineProperty(exports, "__esModule", { value: true });
var Number_1 = require("./Number");
describe("Number testing", function () {
    var config = {
        meta: {
            component: "range",
            help: "age selector",
            sequence: 10,
            step: 5,
            value: 50
        },
        title: "naguvan",
        type: "number"
    };
    test("check number default meta", function () {
        var type = Number_1.Number.create();
        expect(type.meta).not.toBeNull();
        expect(type.meta.component).toBe("text");
        expect(type.meta.sequence).toBeNull();
        expect(type.meta.help).toBeNull();
    });
    test("test number meta", function () {
        var type = Number_1.Number.create(config);
        expect(type.meta).not.toBeNull();
        expect(type.meta.component).toBe("range");
        expect(type.meta.help).toBe("age selector");
        expect(type.meta.sequence).toBe(10);
        expect(type.meta.initial).toBe(50);
        expect(type.meta.step).toBe(5);
    });
    test("create number type", function () {
        var type = Number_1.Number.create(config);
        expect(type.type).toBe("number");
        expect(type.title).toBe("naguvan");
        expect(type.data).toBe(50);
        expect(type.minimum).toBe(null);
        expect(type.maximum).toBe(null);
    });
    test("change number name type", function () {
        var type = Number_1.Number.create(config);
        type.meta.setName("senthilnathan");
        expect(type.meta.name).toBe("senthilnathan");
    });
    test("validate minimum valid", function () {
        var type = Number_1.Number.create(__assign({}, config, { minimum: 10 }));
        type.setValue(12);
        expect(type.data).toBe(12);
        type.validate();
        // expect(type.valid).toBe(true);
        expect(type.errors.slice(0)).toEqual([]);
    });
    test("validate minimum invalid", function () {
        var type = Number_1.Number.create(__assign({}, config, { minimum: 10 }));
        type.setValue(5);
        expect(type.data).toBe(5);
        type.validate();
        expect(type.valid).toBe(false);
        expect(type.errors.slice(0)).toEqual(["should NOT be lesser than 10"]);
    });
    test("validate maximum valid", function () {
        var type = Number_1.Number.create(__assign({}, config, { maximum: 10 }));
        type.setValue(5);
        expect(type.data).toBe(5);
        type.validate();
        expect(type.valid).toBe(true);
        expect(type.errors.slice(0)).toEqual([]);
    });
    test("validate maximum invalid", function () {
        var type = Number_1.Number.create(__assign({}, config, { maximum: 10 }));
        type.setValue(15);
        expect(type.data).toBe(15);
        type.validate();
        expect(type.valid).toBe(false);
        expect(type.errors.slice(0)).toEqual(["should NOT be greater than 10"]);
    });
    test("test invalid multipleOf configuration", function () {
        expect(function () {
            return Number_1.Number.create(__assign({}, config, { multipleOf: 0 }));
        }).toThrowError("multipleOf can not be zero");
        expect(function () {
            return Number_1.Number.create(__assign({}, config, { multipleOf: -10 }));
        }).toThrowError("multipleOf can not be negative");
    });
    test("validate multipleOf valid", function () {
        var type = Number_1.Number.create(__assign({}, config, { multipleOf: 3 }));
        type.setValue(27);
        expect(type.data).toBe(27);
        type.validate();
        expect(type.valid).toBe(true);
        expect(type.errors.slice(0)).toEqual([]);
    });
    test("validate multipleOf invalid", function () {
        var type = Number_1.Number.create(__assign({}, config, { multipleOf: 3 }));
        type.setValue(29);
        expect(type.data).toBe(29);
        type.validate();
        expect(type.valid).toBe(false);
        expect(type.errors.slice(0)).toEqual(["should be multiple of 3"]);
    });
    test("validate const valid", function () {
        var type = Number_1.Number.create(__assign({}, config, { const: 5 }));
        type.setValue(5);
        expect(type.data).toBe(5);
        type.validate();
        expect(type.valid).toBe(true);
        expect(type.errors.slice(0)).toEqual([]);
    });
    test("validate const invalid", function () {
        var type = Number_1.Number.create(__assign({}, config, { const: 5 }));
        type.setValue(10);
        expect(type.data).toBe(10);
        type.validate();
        expect(type.valid).toBe(false);
        expect(type.errors.slice(0)).toEqual(["should be equal to 5"]);
    });
    test("validate enum valid", function () {
        var type = Number_1.Number.create(__assign({}, config, { enum: [5, 10] }));
        type.setValue(5);
        expect(type.data).toBe(5);
        type.validate();
        expect(type.valid).toBe(true);
        expect(type.errors.slice(0)).toEqual([]);
    });
    test("validate enum invalid", function () {
        var type = Number_1.Number.create(__assign({}, config, { enum: [5, 20] }));
        type.setValue(10);
        expect(type.data).toBe(10);
        type.validate();
        expect(type.valid).toBe(false);
        expect(type.errors.slice(0)).toEqual([
            "should be equal to one of the allowed values [5, 20]"
        ]);
    });
});
//# sourceMappingURL=Number.test.js.map