"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var Type_1 = require("./Type");
var mobx_1 = require("mobx");
var utils_1 = require("../utils");
describe("type test cases", function () {
    var Type = Type_1.createType();
    test("create string type ", function () {
        var type = Type.create({
            meta: {
                value: "sk"
            },
            minLength: 4,
            title: "naguvan",
            type: "string"
        });
        expect(type.type).toBe("string");
        expect(type.title).toBe("naguvan");
        expect(type.data).toBe("sk");
        expect(type.minLength).toBe(4);
    });
    test("create number type ", function () {
        var type = Type.create({
            meta: {
                value: 50
            },
            title: "naguvan",
            type: "number"
        });
        expect(type.type).toBe("number");
        expect(type.title).toBe("naguvan");
        expect(type.data).toBe(50);
    });
    test("create boolean type ", function () {
        var type = Type.create({
            meta: {
                value: true
            },
            title: "naguvan",
            type: "boolean"
        });
        expect(type.type).toBe("boolean");
        expect(type.title).toBe("naguvan");
        expect(type.meta.name).toBe(type.title);
        expect(type.data).toBe(true);
    });
    test("create null type ", function () {
        var type = Type.create({
            meta: {
                value: null
            },
            title: "naguvan",
            type: "null"
        });
        expect(type.type).toBe("null");
        expect(type.title).toBe("naguvan");
        expect(type.data).toBe(null);
    });
    test("create object type", function () {
        var type = Type.create({
            properties: {
                age: {
                    meta: {
                        value: 1
                    },
                    title: "age",
                    type: "number"
                },
                name: {
                    meta: {
                        length: 100,
                        value: "naguvan"
                    },
                    title: "name",
                    type: "string"
                }
            },
            title: "naguvan",
            type: "object"
        });
        expect(type.type).toBe("object");
        expect(type.title).toBe("naguvan");
        expect(type.data).toEqual({ name: "naguvan", age: 1 });
        expect(type.additionalProperties).toBeNull();
        expect(type.maxProperties).toBeNull();
        expect(type.minProperties).toBeNull();
        expect(type.properties).not.toBeNull();
        expect(utils_1.keys(mobx_1.toJS(type.properties)).length).toBe(2);
        expect(utils_1.keys(mobx_1.toJS(type.properties))).toEqual(["age", "name"]);
        expect(type.properties.get("name").title).toBe("name");
        expect(type.properties.get("name").data).toBe("naguvan");
        expect(type.properties.get("name").type).toBe("string");
    });
    test("create array type", function () {
        var type = Type.create({
            items: {
                type: "number"
            },
            title: "naguvan",
            type: "array"
        });
        expect(type.type).toBe("array");
        expect(type.title).toBe("naguvan");
        expect(type.data).toEqual([]);
        expect(type.additionalItems).toBeNull();
        expect(type.maxItems).toBeNull();
        expect(type.minItems).toBeNull();
        expect(type.uniqueItems).toBeNull();
        expect(type.items).not.toBeNull();
        expect(type.items.type).toBe("number");
    });
    test("test snapshot create", function () {
        var config = {
            additionalProperties: null,
            maxProperties: null,
            meta: {
                disabled: false,
                mandatory: false,
                name: "",
                visible: true
            },
            minProperties: null,
            properties: {
                age: {
                    meta: {
                        default: 0,
                        disabled: false,
                        initial: 0,
                        mandatory: false,
                        name: "",
                        value: 0,
                        visible: true
                    },
                    multipleOf: 2,
                    title: "age",
                    type: "number"
                },
                name: {
                    meta: {
                        disabled: false,
                        mandatory: false,
                        name: "",
                        value: "",
                        visible: true
                    },
                    minLength: 3,
                    title: "name",
                    type: "string"
                }
            },
            required: null,
            title: "snapshot",
            type: "object"
        };
        var type = Type.create(config);
        expect(type.type).toBe("object");
        expect(type.title).toBe("snapshot");
    });
    test("form sample schema", function () {
        var config = {
            properties: {
                agree: {
                    const: true,
                    meta: {
                        value: false
                    },
                    title: "I agree with your terms",
                    type: "boolean"
                },
                array: {
                    items: {
                        properties: {
                            age: {
                                meta: {
                                    value: 0
                                },
                                minimum: 2,
                                multipleOf: 2,
                                title: "age",
                                type: "number"
                            },
                            name: {
                                minLength: 3,
                                title: "name",
                                type: "string"
                            }
                        },
                        type: "object"
                    },
                    maxItems: 4,
                    minItems: 2,
                    title: "Array",
                    type: "array"
                },
                color: {
                    format: "color",
                    meta: {
                        component: "color"
                    },
                    title: "In which color",
                    type: "string"
                },
                ipv4: {
                    format: "ipv4",
                    maxLength: 20,
                    minLength: 5,
                    title: "ipv4",
                    type: "string"
                },
                name: {
                    meta: {
                        layout: [["first", "last"], "middle", "age"]
                    },
                    properties: {
                        age: {
                            maximum: 10,
                            meta: {
                                sequence: 2,
                                value: 5
                            },
                            minimum: 3,
                            title: "Age",
                            type: "number"
                        },
                        first: {
                            meta: {
                                sequence: 1,
                                value: "naguvan"
                            },
                            minLength: 5,
                            title: "First",
                            type: "string"
                        },
                        last: {
                            meta: {
                                sequence: 2,
                                value: "sk"
                            },
                            minLength: 5,
                            title: "Last",
                            type: "string"
                        },
                        middle: {
                            meta: {
                                sequence: 1,
                                value: "sk"
                            },
                            minLength: 5,
                            title: "Middle",
                            type: "string"
                        }
                    },
                    type: "object"
                },
                size: {
                    maximum: 10,
                    meta: {
                        value: 5
                    },
                    minimum: 3,
                    multipleOf: 3,
                    title: "Size",
                    type: "number"
                },
                title: {
                    meta: {
                        value: "sk"
                    },
                    minLength: 5,
                    title: "Title",
                    type: "string"
                },
                type: {
                    enum: [1, 2],
                    meta: {
                        options: [{ label: "One", value: 1 }, { label: "Two", value: 2 }]
                    },
                    title: "Select a type",
                    type: "number"
                }
            },
            title: "form schema",
            type: "object"
        };
        var type = Type.create(config);
        expect(type.type).toBe("object");
        expect(type.title).toBe("form schema");
        expect(type.data).toEqual({
            agree: false,
            array: [],
            color: "",
            ipv4: "",
            name: {
                age: 5,
                first: "naguvan",
                last: "sk",
                middle: "sk"
            },
            size: 5,
            title: "sk",
            type: 0
        });
        var color = type.getProperty("color");
        color.setValue("#ffffff");
        expect(type.data).toEqual({
            agree: false,
            array: [],
            color: "#ffffff",
            ipv4: "",
            name: {
                age: 5,
                first: "naguvan",
                last: "sk",
                middle: "sk"
            },
            size: 5,
            title: "sk",
            type: 0
        });
        type.validate();
        expect(type.valid).toBe(false);
        var errors = type.getFieldErrors();
        expect(errors.errors).toEqual([]);
        var properties = errors.properties;
        expect(properties.agree).toEqual(["should be equal to true"]);
        expect(properties.array.errors).toEqual([
            "should NOT have less than 2 items"
        ]);
        expect(properties.color).toEqual([]);
        expect(properties.ipv4).toEqual([
            "should NOT be shorter than 5 characters",
            "should match format ipv4"
        ]);
        expect(properties.name).toEqual({
            errors: [],
            properties: {
                age: [],
                first: [],
                last: ["should NOT be shorter than 5 characters"],
                middle: ["should NOT be shorter than 5 characters"]
            }
        });
        expect(properties.size).toEqual(["should be multiple of 3"]);
        expect(properties.type).toEqual([
            "should be equal to one of the allowed values [1, 2]"
        ]);
        type.sync({ agree: true, size: 6, name: { last: "kannapiran" } });
        expect(type.getProperty("size").valid).toBe(true);
        expect(type.getProperty("agree").valid).toBe(true);
        var name = type.getProperty("name");
        expect(name.getFieldErrors()).toEqual({
            errors: [],
            properties: {
                age: [],
                first: [],
                last: [],
                middle: ["should NOT be shorter than 5 characters"]
            }
        });
        type.sync({ title: "senthilnathan", type: 2 });
        var options = type.getProperty("type").meta.options;
        expect(options).not.toBeFalsy();
        expect(options.length).toBe(2);
        expect(type.getProperty("title").valid).toBe(true);
        expect(type.getProperty("type").valid).toBe(true);
        var ipv4 = type.getProperty("ipv4");
        ipv4.sync("12.45.67.70");
        expect(type.getProperty("ipv4").valid).toBe(true);
        type.sync({ array: [{}] });
        var array = type.getProperty("array");
        array.push();
        var item = array.elements[0];
        expect(item.valid).toBe(false);
        expect(array.getFieldErrors()).toEqual({
            errors: [],
            items: [
                {
                    errors: [],
                    properties: {
                        age: ["should NOT be lesser than 2"],
                        name: ["should NOT be shorter than 3 characters"]
                    }
                },
                {
                    errors: [],
                    properties: {
                        age: ["should NOT be lesser than 2"],
                        name: ["should NOT be shorter than 3 characters"]
                    }
                }
            ]
        });
        type.sync({
            name: { middle: "senthilnathan" }
        });
        array.updateIndexValue(0, { age: 4, name: "naguvan" });
        array.updateIndexValue(1, { age: 5, name: "naguvan" });
        expect(item.valid).toBe(false);
        type.validate();
        expect(item.valid).toBe(true);
        expect(type.data).toEqual({
            agree: true,
            array: [
                {
                    age: 4,
                    name: "naguvan"
                },
                {
                    age: 5,
                    name: "naguvan"
                }
            ],
            color: "#ffffff",
            ipv4: "12.45.67.70",
            name: {
                age: 5,
                first: "naguvan",
                last: "kannapiran",
                middle: "senthilnathan"
            },
            size: 6,
            title: "senthilnathan",
            type: 2
        });
    });
});
//# sourceMappingURL=Type.test.js.map